==> 0.1.0.tar.gz: lib/src/property.dart <==
part of frp;

class Property<T>{
  
  //--------------------------------------------------------------------------
  //
  //                    Constructor
  //
  //--------------------------------------------------------------------------
  Property([T v]){
    
    if(v!=null)
      value = v;
  }
  
  //--------------------------------------------------------------------------
  //
  //                    Properties
  //
  //--------------------------------------------------------------------------
  
  //========================================
  //            VALUE
  //========================================
  T value;
  
  //========================================
  //            STREAM
  //========================================
  StreamController<T> _streamController = new StreamController<T>();
  Stream<T> get stream=>_streamController.stream;
  
  //========================================
  //  OVERLOAD < AS STREAM ASSIGNMENT
  //========================================
  operator <(Stream s){
    s.listen((data)=>_streamController.add(data));
  }
  
  //--------------------------------------------------------------------------
  //
  //                    Methods
  //
  //--------------------------------------------------------------------------
  void derive(List<Property> properties, Function mergeFunc){
    List<Stream> streams = new List<Stream>();
    properties.forEach((Property p)=>streams.add(p.stream));
    this < new StreamMerger(streams, mergeFunc).stream;
  }
  
  void fromConstant(T constant){
    value = constant;
  }
}

==> 0.1.1.tar.gz: lib/src/property.dart <==
part of frp;

class Property<T>{
  
  //--------------------------------------------------------------------------
  //
  //                    Constructor
  //
  //--------------------------------------------------------------------------
  Property([T v]){
    
    if(v!=null)
      value = v;
  }
  
  //--------------------------------------------------------------------------
  //
  //                    Properties
  //
  //--------------------------------------------------------------------------
  
  //========================================
  //            VALUE
  //========================================
  T value;
  
  //========================================
  //            STREAM
  //========================================
  StreamController<T> _streamController = new StreamController<T>();
  Stream<T> get stream=>_streamController.stream;
  
  //========================================
  //  OVERLOAD < AS STREAM ASSIGNMENT
  //========================================
  operator <(Stream s){
    s.listen((data)=>_streamController.add(data));
  }
  
  //--------------------------------------------------------------------------
  //
  //                    Methods
  //
  //--------------------------------------------------------------------------
  void derive(Property p, Function deriveFunc){
    this < p.stream.map(deriveFunc);
  }
  
  void merge(List<Property> properties, Function mergeFunc){
    List<Stream> streams = new List<Stream>();
    properties.forEach((Property p)=>streams.add(p.stream));
    this < new StreamMerger(streams, mergeFunc).stream;
  }
  
  void fromConstant(T constant){
    value = constant;
  }
}
